'''
# Hyperledger Fabric on Amazon Managed Blockchain

This repository contains an L2 CDK construct to deploy a Hyperledger
Fabric network running on Amazon Managed Blockchain. It currently builds
out a member and its nodes, but the following enhanced functionality
is planned for future releases:

* Enable CA, node, and chaincode logging
* Enroll users, storing their credentials in Secrets Manager
* Create channels on nodes
* Instantiate chaincode on nodes
* Set up a VPC and associated endpoint for accessing the network

## Installation

The construct is available for both TypeScript and Python CDK projects.
It can be installed with the following:

* TypeScript: `npm install --save cdk-hyperledger-fabric-network`
* Python: `pip3 install cdk-hyperledger-fabric-network`

Note that this construct requires [AWS CDK v2](https://docs.aws.amazon.com/cdk/v2/guide/getting_started.html#getting_started_install).

## Usage

A minimally complete deployment is shown below. By default, a standard network
will be created running Hyperledger Fabric 1.4 with a single `bc.t3.small` node.

```python
import { Stack, StackProps } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { HyperledgerFabricNetwork } from 'cdk-hyperledger-fabric-network';

class MyStack extends Stack {
  constructor(scope: Construct, id: string, props?: StackProps) {
    super(scope, id, props);
    new HyperledgerFabricNetwork(this, 'Example', {
      networkName: 'MyNetwork',
      memberName: 'MyMember',
    });
  });
}
```

The equivalent Python code is as follows:

```python
from aws_cdk import Stack
from cdk_hyperledger_fabric_network import HyperledgerFabricNetwork

class MyStack(Stack):
    def __init__(self, scope, id, **kwargs):
        super().__init__(scope, id, **kwargs)
        HyperledgerFabricNetwork(
            self, 'Example',
            network_name='MyNetwork',
            member_name='MyMember',
        )
```

The following is a more complex instantiation illustrating some of the options available.

```python
new HyperledgerFabricNetwork(this, 'Example', {
  networkName: 'MyNetwork',
  networkDescription: 'This is my Hyperledger Fabric network',
  memberName: 'MyMember',
  networkDescription: 'This is my Hyperledger Fabric member',
  frameworkVersion: hyperledger.FrameworkVersion.VERSION_1_2,
  proposalDurationInHours: 48,
  thresholdPercentage: 75,
  nodes: [
    {
      availabilityZone: 'us-east-1a',
      instanceType: hyperledger.InstanceType.STANDARD5_LARGE,
    },
    {
      availabilityZone: 'us-east-1b',
      instanceType: hyperledger.InstanceType.STANDARD5_LARGE,
    },
  ],
});
```

See the [API Documentation](API.md) for details on all available input and output parameters.

## References

* [AWS CDK](https://docs.aws.amazon.com/cdk/v2/guide/home.html)
* [Amazon Managed Blockchain](https://aws.amazon.com/managed-blockchain/)
* [Hyperledger Fabric](https://hyperledger-fabric.readthedocs.io/)
* [Node Fabric SDK](https://hyperledger.github.io/fabric-sdk-node/release-1.4/index.html)
* [Fabric Chaincode Node](https://hyperledger.github.io/fabric-chaincode-node/)

## Contributing

Pull requests are welcomed. Please review the [Contributing Guidelines](CONTRIBUTING.md)
and the [Code of Conduct](CODE_OF_CONDUCT.md).

## Security

See [CONTRIBUTING](CONTRIBUTING.md#security-issue-notifications) for more information.

## Authors

* Jud Neer (judneer@amazon.com)

## License

This project is licensed under the MIT-0 License. See the [LICENSE](LICENSE) file for details.
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *

import aws_cdk.aws_secretsmanager
import aws_cdk.custom_resources
import constructs


@jsii.enum(jsii_type="cdk-hyperledger-fabric-network.FrameworkVersion")
class FrameworkVersion(enum.Enum):
    VERSION_1_2 = "VERSION_1_2"
    VERSION_1_4 = "VERSION_1_4"


class HyperledgerFabricNetwork(
    constructs.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-hyperledger-fabric-network.HyperledgerFabricNetwork",
):
    '''Creates a Hyperledger Fabric network on Amazon Managed Blockchain.'''

    def __init__(
        self,
        scope: constructs.Construct,
        id: builtins.str,
        *,
        member_name: builtins.str,
        network_name: builtins.str,
        framework_version: typing.Optional[FrameworkVersion] = None,
        member_description: typing.Optional[builtins.str] = None,
        network_description: typing.Optional[builtins.str] = None,
        network_edition: typing.Optional["NetworkEdition"] = None,
        nodes: typing.Optional[typing.Sequence["HyperledgerFabricNodeProps"]] = None,
        proposal_duration_in_hours: typing.Optional[jsii.Number] = None,
        threshold_comparator: typing.Optional["ThresholdComparator"] = None,
        threshold_percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param member_name: Managed Blockchain member name.
        :param network_name: Managed Blockchain network name.
        :param framework_version: Hyperledger Fabric framework version. Default: - FrameworkVersion.VERSION_1_4
        :param member_description: Managed Blockchain member description. Default: - Set to match member name
        :param network_description: Managed Blockchain network description. Default: - Set to match network name
        :param network_edition: Managed Blockchain network edition. Default: - NetworkEdition.STANDARD
        :param nodes: List of nodes to create on the network. Default: - One node with default configuration
        :param proposal_duration_in_hours: The duration from the time that a proposal is created until it expires. Default: - 24 hours
        :param threshold_comparator: Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved. Default: - GREATER_THAN
        :param threshold_percentage: The percentage of votes among all members that must be yes for a proposal to be approved. Default: - 50 percent
        '''
        props = HyperledgerFabricNetworkProps(
            member_name=member_name,
            network_name=network_name,
            framework_version=framework_version,
            member_description=member_description,
            network_description=network_description,
            network_edition=network_edition,
            nodes=nodes,
            proposal_duration_in_hours=proposal_duration_in_hours,
            threshold_comparator=threshold_comparator,
            threshold_percentage=threshold_percentage,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPasswordSecret")
    def admin_password_secret(self) -> aws_cdk.aws_secretsmanager.Secret:
        '''Secret ARN for the Hyperledger Fabric admin password.'''
        return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "adminPasswordSecret"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminPrivateKeySecret")
    def admin_private_key_secret(self) -> aws_cdk.aws_secretsmanager.Secret:
        '''Secret for Hyperledger Fabric admin private key.'''
        return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "adminPrivateKeySecret"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="adminSignedCertSecret")
    def admin_signed_cert_secret(self) -> aws_cdk.aws_secretsmanager.Secret:
        '''Secret for Hyperledger Fabric admin signed certificate.'''
        return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "adminSignedCertSecret"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="caEndpoint")
    def ca_endpoint(self) -> builtins.str:
        '''Managed Blockchain member CA endpoint.'''
        return typing.cast(builtins.str, jsii.get(self, "caEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="frameworkVersion")
    def framework_version(self) -> FrameworkVersion:
        '''Hyperledger Fabric framework version.'''
        return typing.cast(FrameworkVersion, jsii.get(self, "frameworkVersion"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberDescription")
    def member_description(self) -> builtins.str:
        '''Managed Blockchain member description.'''
        return typing.cast(builtins.str, jsii.get(self, "memberDescription"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberId")
    def member_id(self) -> builtins.str:
        '''Managed Blockchain member identifier generated on construction.'''
        return typing.cast(builtins.str, jsii.get(self, "memberId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberName")
    def member_name(self) -> builtins.str:
        '''Managed Blockchain member name.'''
        return typing.cast(builtins.str, jsii.get(self, "memberName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkDescription")
    def network_description(self) -> builtins.str:
        '''Managed Blockchain network description.'''
        return typing.cast(builtins.str, jsii.get(self, "networkDescription"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkEdition")
    def network_edition(self) -> "NetworkEdition":
        '''Managed Blockchain network edition.'''
        return typing.cast("NetworkEdition", jsii.get(self, "networkEdition"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        '''Managed Blockchain network identifier generated on construction.'''
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkName")
    def network_name(self) -> builtins.str:
        '''Managed Blockchain network name.'''
        return typing.cast(builtins.str, jsii.get(self, "networkName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodes")
    def nodes(self) -> typing.List["HyperledgerFabricNode"]:
        '''List of nodes created in the network.'''
        return typing.cast(typing.List["HyperledgerFabricNode"], jsii.get(self, "nodes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ordererEndpoint")
    def orderer_endpoint(self) -> builtins.str:
        '''Managed Blockchain network ordering service endpoint.'''
        return typing.cast(builtins.str, jsii.get(self, "ordererEndpoint"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="proposalDurationInHours")
    def proposal_duration_in_hours(self) -> jsii.Number:
        '''The duration from the time that a proposal is created until it expires.'''
        return typing.cast(jsii.Number, jsii.get(self, "proposalDurationInHours"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thresholdComparator")
    def threshold_comparator(self) -> "ThresholdComparator":
        '''Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved.'''
        return typing.cast("ThresholdComparator", jsii.get(self, "thresholdComparator"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="thresholdPercentage")
    def threshold_percentage(self) -> jsii.Number:
        '''The percentage of votes among all members that must be yes for a proposal to be approved.'''
        return typing.cast(jsii.Number, jsii.get(self, "thresholdPercentage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="vpcEndpointServiceName")
    def vpc_endpoint_service_name(self) -> builtins.str:
        '''Managed Blockchain network VPC endpoint service name.'''
        return typing.cast(builtins.str, jsii.get(self, "vpcEndpointServiceName"))


@jsii.data_type(
    jsii_type="cdk-hyperledger-fabric-network.HyperledgerFabricNetworkProps",
    jsii_struct_bases=[],
    name_mapping={
        "member_name": "memberName",
        "network_name": "networkName",
        "framework_version": "frameworkVersion",
        "member_description": "memberDescription",
        "network_description": "networkDescription",
        "network_edition": "networkEdition",
        "nodes": "nodes",
        "proposal_duration_in_hours": "proposalDurationInHours",
        "threshold_comparator": "thresholdComparator",
        "threshold_percentage": "thresholdPercentage",
    },
)
class HyperledgerFabricNetworkProps:
    def __init__(
        self,
        *,
        member_name: builtins.str,
        network_name: builtins.str,
        framework_version: typing.Optional[FrameworkVersion] = None,
        member_description: typing.Optional[builtins.str] = None,
        network_description: typing.Optional[builtins.str] = None,
        network_edition: typing.Optional["NetworkEdition"] = None,
        nodes: typing.Optional[typing.Sequence["HyperledgerFabricNodeProps"]] = None,
        proposal_duration_in_hours: typing.Optional[jsii.Number] = None,
        threshold_comparator: typing.Optional["ThresholdComparator"] = None,
        threshold_percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''Construct properties for ``HyperledgerFabricNetwork``.

        :param member_name: Managed Blockchain member name.
        :param network_name: Managed Blockchain network name.
        :param framework_version: Hyperledger Fabric framework version. Default: - FrameworkVersion.VERSION_1_4
        :param member_description: Managed Blockchain member description. Default: - Set to match member name
        :param network_description: Managed Blockchain network description. Default: - Set to match network name
        :param network_edition: Managed Blockchain network edition. Default: - NetworkEdition.STANDARD
        :param nodes: List of nodes to create on the network. Default: - One node with default configuration
        :param proposal_duration_in_hours: The duration from the time that a proposal is created until it expires. Default: - 24 hours
        :param threshold_comparator: Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved. Default: - GREATER_THAN
        :param threshold_percentage: The percentage of votes among all members that must be yes for a proposal to be approved. Default: - 50 percent
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "member_name": member_name,
            "network_name": network_name,
        }
        if framework_version is not None:
            self._values["framework_version"] = framework_version
        if member_description is not None:
            self._values["member_description"] = member_description
        if network_description is not None:
            self._values["network_description"] = network_description
        if network_edition is not None:
            self._values["network_edition"] = network_edition
        if nodes is not None:
            self._values["nodes"] = nodes
        if proposal_duration_in_hours is not None:
            self._values["proposal_duration_in_hours"] = proposal_duration_in_hours
        if threshold_comparator is not None:
            self._values["threshold_comparator"] = threshold_comparator
        if threshold_percentage is not None:
            self._values["threshold_percentage"] = threshold_percentage

    @builtins.property
    def member_name(self) -> builtins.str:
        '''Managed Blockchain member name.'''
        result = self._values.get("member_name")
        assert result is not None, "Required property 'member_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def network_name(self) -> builtins.str:
        '''Managed Blockchain network name.'''
        result = self._values.get("network_name")
        assert result is not None, "Required property 'network_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def framework_version(self) -> typing.Optional[FrameworkVersion]:
        '''Hyperledger Fabric framework version.

        :default: - FrameworkVersion.VERSION_1_4
        '''
        result = self._values.get("framework_version")
        return typing.cast(typing.Optional[FrameworkVersion], result)

    @builtins.property
    def member_description(self) -> typing.Optional[builtins.str]:
        '''Managed Blockchain member description.

        :default: - Set to match member name
        '''
        result = self._values.get("member_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_description(self) -> typing.Optional[builtins.str]:
        '''Managed Blockchain network description.

        :default: - Set to match network name
        '''
        result = self._values.get("network_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def network_edition(self) -> typing.Optional["NetworkEdition"]:
        '''Managed Blockchain network edition.

        :default: - NetworkEdition.STANDARD
        '''
        result = self._values.get("network_edition")
        return typing.cast(typing.Optional["NetworkEdition"], result)

    @builtins.property
    def nodes(self) -> typing.Optional[typing.List["HyperledgerFabricNodeProps"]]:
        '''List of nodes to create on the network.

        :default: - One node with default configuration
        '''
        result = self._values.get("nodes")
        return typing.cast(typing.Optional[typing.List["HyperledgerFabricNodeProps"]], result)

    @builtins.property
    def proposal_duration_in_hours(self) -> typing.Optional[jsii.Number]:
        '''The duration from the time that a proposal is created until it expires.

        :default: - 24 hours
        '''
        result = self._values.get("proposal_duration_in_hours")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def threshold_comparator(self) -> typing.Optional["ThresholdComparator"]:
        '''Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved.

        :default: - GREATER_THAN
        '''
        result = self._values.get("threshold_comparator")
        return typing.cast(typing.Optional["ThresholdComparator"], result)

    @builtins.property
    def threshold_percentage(self) -> typing.Optional[jsii.Number]:
        '''The percentage of votes among all members that must be yes for a proposal to be approved.

        :default: - 50 percent
        '''
        result = self._values.get("threshold_percentage")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HyperledgerFabricNetworkProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class HyperledgerFabricNode(
    constructs.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-hyperledger-fabric-network.HyperledgerFabricNode",
):
    '''Creates a Hyperledger Fabric node on an Amazon Managed Blockchain network.'''

    def __init__(
        self,
        scope: HyperledgerFabricNetwork,
        id: builtins.str,
        *,
        availability_zone: typing.Optional[builtins.str] = None,
        instance_type: typing.Optional["InstanceType"] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param availability_zone: The Availability Zone in which the node will be created. Default: - The first AZ in the region
        :param instance_type: The Amazon Managed Blockchain instance type for the node. Default: - BURSTABLE3_SMALL
        '''
        props = HyperledgerFabricNodeProps(
            availability_zone=availability_zone, instance_type=instance_type
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="constructNodes") # type: ignore[misc]
    @builtins.classmethod
    def construct_nodes(
        cls,
        scope: HyperledgerFabricNetwork,
        node_props: typing.Optional[typing.Sequence["HyperledgerFabricNodeProps"]] = None,
    ) -> typing.List["HyperledgerFabricNode"]:
        '''
        :param scope: -
        :param node_props: -
        '''
        return typing.cast(typing.List["HyperledgerFabricNode"], jsii.sinvoke(cls, "constructNodes", [scope, node_props]))

    @jsii.member(jsii_name="fetchData")
    def fetch_data(
        self,
        data_sdk_call_policy: aws_cdk.custom_resources.AwsCustomResourcePolicy,
    ) -> None:
        '''
        :param data_sdk_call_policy: -
        '''
        return typing.cast(None, jsii.invoke(self, "fetchData", [data_sdk_call_policy]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> builtins.str:
        '''The Availability Zone in which the node exists.'''
        return typing.cast(builtins.str, jsii.get(self, "availabilityZone"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> "InstanceType":
        '''The Amazon Managed Blockchain instance type for the node.'''
        return typing.cast("InstanceType", jsii.get(self, "instanceType"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memberId")
    def member_id(self) -> builtins.str:
        '''Managed Blockchain member identifier.'''
        return typing.cast(builtins.str, jsii.get(self, "memberId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkId")
    def network_id(self) -> builtins.str:
        '''Managed Blockchain network identifier.'''
        return typing.cast(builtins.str, jsii.get(self, "networkId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeId")
    def node_id(self) -> builtins.str:
        '''Managed Blockchain node identifier generated on construction.'''
        return typing.cast(builtins.str, jsii.get(self, "nodeId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "endpoint"))

    @endpoint.setter
    def endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="eventEndpoint")
    def event_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "eventEndpoint"))

    @event_endpoint.setter
    def event_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "eventEndpoint", value)


@jsii.data_type(
    jsii_type="cdk-hyperledger-fabric-network.HyperledgerFabricNodeProps",
    jsii_struct_bases=[],
    name_mapping={
        "availability_zone": "availabilityZone",
        "instance_type": "instanceType",
    },
)
class HyperledgerFabricNodeProps:
    def __init__(
        self,
        *,
        availability_zone: typing.Optional[builtins.str] = None,
        instance_type: typing.Optional["InstanceType"] = None,
    ) -> None:
        '''Construct properties for ``HyperledgerFabricNode``.

        :param availability_zone: The Availability Zone in which the node will be created. Default: - The first AZ in the region
        :param instance_type: The Amazon Managed Blockchain instance type for the node. Default: - BURSTABLE3_SMALL
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if instance_type is not None:
            self._values["instance_type"] = instance_type

    @builtins.property
    def availability_zone(self) -> typing.Optional[builtins.str]:
        '''The Availability Zone in which the node will be created.

        :default: - The first AZ in the region
        '''
        result = self._values.get("availability_zone")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def instance_type(self) -> typing.Optional["InstanceType"]:
        '''The Amazon Managed Blockchain instance type for the node.

        :default: - BURSTABLE3_SMALL
        '''
        result = self._values.get("instance_type")
        return typing.cast(typing.Optional["InstanceType"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HyperledgerFabricNodeProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-hyperledger-fabric-network.InstanceType")
class InstanceType(enum.Enum):
    '''Supported instance types for Managed Blockchain nodes.'''

    BURSTABLE3_SMALL = "BURSTABLE3_SMALL"
    BURSTABLE3_MEDIUM = "BURSTABLE3_MEDIUM"
    BURSTABLE3_LARGE = "BURSTABLE3_LARGE"
    BURSTABLE3_XLARGE = "BURSTABLE3_XLARGE"
    STANDARD5_LARGE = "STANDARD5_LARGE"
    STANDARD5_XLARGE = "STANDARD5_XLARGE"
    STANDARD5_XLARGE2 = "STANDARD5_XLARGE2"
    STANDARD5_XLARGE4 = "STANDARD5_XLARGE4"
    COMPUTE5_LARGE = "COMPUTE5_LARGE"
    COMPUTE5_XLARGE = "COMPUTE5_XLARGE"
    COMPUTE5_XLARGE2 = "COMPUTE5_XLARGE2"
    COMPUTE5_XLARGE4 = "COMPUTE5_XLARGE4"


@jsii.enum(jsii_type="cdk-hyperledger-fabric-network.NetworkEdition")
class NetworkEdition(enum.Enum):
    STARTER = "STARTER"
    STANDARD = "STANDARD"


@jsii.enum(jsii_type="cdk-hyperledger-fabric-network.ThresholdComparator")
class ThresholdComparator(enum.Enum):
    GREATER_THAN = "GREATER_THAN"
    GREATER_THAN_OR_EQUAL_TO = "GREATER_THAN_OR_EQUAL_TO"


__all__ = [
    "FrameworkVersion",
    "HyperledgerFabricNetwork",
    "HyperledgerFabricNetworkProps",
    "HyperledgerFabricNode",
    "HyperledgerFabricNodeProps",
    "InstanceType",
    "NetworkEdition",
    "ThresholdComparator",
]

publication.publish()
